==> ace_5.6.3.orig.tar.gz: ACE_wrappers/TAO/tests/Typedef_String_Array/client.cpp <==
// $Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $

#include "testC.h"
#include "ace/Get_Opt.h"

ACE_RCSID(StringArray, client, "$Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $")

const char *ior = "file://server.ior";

int
parse_args (int argc, char *argv[])
{
  ACE_Get_Opt get_opts (argc, argv, "k:");
  int c;

  while ((c = get_opts ()) != -1)
    switch (c)
      {
      case 'k':
        ior = get_opts.opt_arg ();
        break;

      case '?':
      default:
        ACE_ERROR_RETURN ((LM_ERROR,
                           "usage:  %s "
                           "-k <ior> "
                           "\n",
                           argv [0]),
                          -1);
      }
  // Indicates sucessful parsing of the command line
  return 0;
}

int
ACE_TMAIN(int argc, ACE_TCHAR *argv[])
{
  try
    {
      CORBA::ORB_var orb =
        CORBA::ORB_init (argc, argv);

      if (parse_args (argc, argv) != 0)
        return 1;

      CORBA::Object_var tmp =
        orb->string_to_object(ior);

      SimpleStrings_var server =
        SimpleStrings::_narrow(tmp.in ());

      if (CORBA::is_nil (server.in ()))
        {
          ACE_ERROR_RETURN ((LM_DEBUG,
                             "Nil SimpleStrings reference <%s>\n",
                             ior),
                            1);
        }

      ArrayOfString_var the_strings;
      server->get_strings (the_strings.out ());

      for(size_t i = 0; i < 15; i++)
        {
          ACE_DEBUG ((LM_DEBUG, "%s\n", the_strings[i].in ()));
        }

      orb->destroy ();
    }
  catch (const CORBA::Exception& ex)
    {
      ex._tao_print_exception ("Exception caught:");
      return 1;
    }

  return 0;
}

==> ace_5.7.7.orig.tar.gz: ACE_wrappers/TAO/tests/Typedef_String_Array/client.cpp <==
// $Id: client.cpp 83141 2008-10-12 18:12:48Z johnnyw $

#include "testC.h"
#include "ace/Get_Opt.h"

ACE_RCSID(StringArray, client, "$Id: client.cpp 83141 2008-10-12 18:12:48Z johnnyw $")

const ACE_TCHAR *ior = ACE_TEXT("file://server.ior");

int
parse_args (int argc, ACE_TCHAR *argv[])
{
  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:"));
  int c;

  while ((c = get_opts ()) != -1)
    switch (c)
      {
      case 'k':
        ior = get_opts.opt_arg ();
        break;

      case '?':
      default:
        ACE_ERROR_RETURN ((LM_ERROR,
                           "usage:  %s "
                           "-k <ior> "
                           "\n",
                           argv [0]),
                          -1);
      }
  // Indicates sucessful parsing of the command line
  return 0;
}

int
ACE_TMAIN(int argc, ACE_TCHAR *argv[])
{
  try
    {
      CORBA::ORB_var orb =
        CORBA::ORB_init (argc, argv);

      if (parse_args (argc, argv) != 0)
        return 1;

      CORBA::Object_var tmp =
        orb->string_to_object(ior);

      SimpleStrings_var server =
        SimpleStrings::_narrow(tmp.in ());

      if (CORBA::is_nil (server.in ()))
        {
          ACE_ERROR_RETURN ((LM_DEBUG,
                             "Nil SimpleStrings reference <%s>\n",
                             ior),
                            1);
        }

      ArrayOfString_var the_strings;
      server->get_strings (the_strings.out ());

      for(size_t i = 0; i < 15; i++)
        {
          ACE_DEBUG ((LM_DEBUG, "%C\n", the_strings[i].in ()));
        }

      orb->destroy ();
    }
  catch (const CORBA::Exception& ex)
    {
      ex._tao_print_exception ("Exception caught:");
      return 1;
    }

  return 0;
}
